NaMaster: nmt_flatsky_info Struct Reference

NaMaster

- Main Page
- Data Structures
- Files

- Data Structures
- Data Structure Index
- Data Fields

Data Fields
nmt_flatsky_info Struct Reference

Flat-sky information. More...

`#include <namaster.h>`

## Data Fields
int | nx
| Number of grid points in the x dimension. More...
int | ny
| Number of grid points in the y dimension. More...
long | npix
| Total number of pixels (given by `nx` * `ny`. More...
flouble | lx
| Length of the x dimension (in steradians) More...
flouble | ly
| Length of the y dimension (in steradians) More...
flouble | pixsize
| Pixel area (given by `lx` * `ly` / ( `nx` * `ny`)) More...
int | n_ell
| Number of |k|-values for Fourier-space sampling. More...
flouble | dell
| Width of the Fourier-space rings. This is found as min(2 π / `lx`,2 π / `ly`). More...
flouble | i_dell
| 1 / `dell` More...
flouble * | ell_min
| Array of `n_ell` values containing the lower edges of each of the |k| rings. More...

## Detailed Description

Flat-sky information.

This structure contains all the information defining a given rectangular flat-sky patch. The structure also contains information about the optimal way of sampling the Fourier version of this patch into rings of |k|.

## Field Documentation

flouble nmt_flatsky_info::dell

Width of the Fourier-space rings. This is found as min(2 π / `lx`,2 π / `ly`).

flouble* nmt_flatsky_info::ell_min

Array of `n_ell` values containing the lower edges of each of the |k| rings.

flouble nmt_flatsky_info::i_dell

1 / `dell`

flouble nmt_flatsky_info::lx

Length of the x dimension (in steradians)

flouble nmt_flatsky_info::ly

Length of the y dimension (in steradians)

int nmt_flatsky_info::n_ell

Number of |k|-values for Fourier-space sampling.

long nmt_flatsky_info::npix

Total number of pixels (given by `nx` * `ny`.

int nmt_flatsky_info::nx

Number of grid points in the x dimension.

int nmt_flatsky_info::ny

Number of grid points in the y dimension.

flouble nmt_flatsky_info::pixsize

Pixel area (given by `lx` * `ly` / ( `nx` * `ny`))

The documentation for this struct was generated from the following file:

- namaster.h